#
# spec file for package python-docutils
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-docutils
Version:        0.12
Release:        2.5
Summary:        Python Documentation Utilities
License:        Python-2.0 and BSD-2-Clause and GPL-2.0+ and GPL-3.0+ and SUSE-Public-Domain
Group:          Development/Languages/Python
Url:            https://pypi.python.org/pypi/docutils/
Source:         https://pypi.python.org/packages/source/d/docutils/docutils-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-nose
BuildRequires:  python-xml
Requires:       python-xml
Provides:       docutils = %{version}
Obsoletes:      docutils < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description
Docutils is a modular system for processing documentation into useful formats,
such as HTML, XML, and LaTeX. For input Docutils supports reStructuredText, an
easy-to-read, what-you-see-is-what-you-get plaintext markup syntax.

%prep
%setup -n docutils-%{version}
# Remove useless ".py" ending from executables:
for i in tools/rst*; do mv "$i" "${i/.py}-%{py_ver}"; done
sed -i "s|'tools/\(rst.*\)\.py'|'tools/\1-%{py_ver}'|" setup.py
# Remove shebang from non-executable files
for i in {'code_analyzer','error_reporting','punctuation_chars','smartquotes','math/latex2mathml','math/math2html'}; do 
sed -i -e "1d" "docutils/utils/$i.py"
done
sed -i -e "1d" "docutils/writers/xetex/__init__.py"

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
binaries="rst2html rst2latex rst2man rst2odt rst2odt_prepstyles rst2pseudoxml rst2s5 rst2xetex rst2xml rstpep2html"
for p in $binaries ; do
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
done

%check
nosetests

%post
%_sbindir/update-alternatives \
    --install %{_bindir}/rst2html rst2html %{_bindir}/rst2html-%{py_ver} 20 \
    --slave %{_bindir}/rst2latex rst2latex %{_bindir}/rst2latex-%{py_ver} \
    --slave %{_bindir}/rst2man rst2man %{_bindir}/rst2man-%{py_ver} \
    --slave %{_bindir}/rst2odt rst2odt %{_bindir}/rst2odt-%{py_ver} \
    --slave %{_bindir}/rst2odt_prepstyles rst2odt_prepstyles %{_bindir}/rst2odt_prepstyles-%{py_ver} \
    --slave %{_bindir}/rst2pseudoxml rst2pseudoxml %{_bindir}/rst2pseudoxml-%{py_ver} \
    --slave %{_bindir}/rst2s5 rst2s5 %{_bindir}/rst2s5-%{py_ver} \
    --slave %{_bindir}/rst2xetex rst2xetex %{_bindir}/rst2xetex-%{py_ver} \
    --slave %{_bindir}/rst2xml rst2xml %{_bindir}/rst2xml-%{py_ver} \
    --slave %{_bindir}/rstpep2html rstpep2html %{_bindir}/rstpep2html-%{py_ver}

%preun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove rst2html %{_bindir}/rst2html-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc COPYING.txt FAQ.txt HISTORY.txt README.txt THANKS.txt BUGS.txt docs/* licenses
%{_bindir}/rst2html
%{_bindir}/rst2latex
%{_bindir}/rst2man
%{_bindir}/rst2odt
%{_bindir}/rst2odt_prepstyles
%{_bindir}/rst2pseudoxml
%{_bindir}/rst2s5
%{_bindir}/rst2xetex
%{_bindir}/rst2xml
%{_bindir}/rstpep2html
%{_bindir}/rst2html-%{py_ver}
%{_bindir}/rst2latex-%{py_ver}
%{_bindir}/rst2man-%{py_ver}
%{_bindir}/rst2odt-%{py_ver}
%{_bindir}/rst2odt_prepstyles-%{py_ver}
%{_bindir}/rst2pseudoxml-%{py_ver}
%{_bindir}/rst2s5-%{py_ver}
%{_bindir}/rst2xetex-%{py_ver}
%{_bindir}/rst2xml-%{py_ver}
%{_bindir}/rstpep2html-%{py_ver}
%ghost %{_sysconfdir}/alternatives/rst2html
%ghost %{_sysconfdir}/alternatives/rst2latex
%ghost %{_sysconfdir}/alternatives/rst2man
%ghost %{_sysconfdir}/alternatives/rst2odt
%ghost %{_sysconfdir}/alternatives/rst2odt_prepstyles
%ghost %{_sysconfdir}/alternatives/rst2pseudoxml
%ghost %{_sysconfdir}/alternatives/rst2s5
%ghost %{_sysconfdir}/alternatives/rst2xetex
%ghost %{_sysconfdir}/alternatives/rst2xml
%ghost %{_sysconfdir}/alternatives/rstpep2html
%{python_sitelib}/docutils/
%{python_sitelib}/docutils-%{version}-py%{py_ver}.egg-info

%changelog
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Oct 29 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 0.12
  * docs/ref/rst/directives.txt
  - Update "math" and "csv-table" descriptions.
  * docutils/parsers/rst/directives/images.py
  - Fix [258] figwidth="image" generates unitless width value.
  * docutils/parsers/rst/states.py
  - Improve error report when a non-ASCII character is specified as
    delimiter, quote or escape character under Python 2.
    Fixes [ 249 ] and [ 250 ].
  * docutils/writers/html4css1/__init__.py
  - Don't add newline after inline math.
    Thanks to Yury G. Kudryashov for the patch.
  * docutils/writers/latex2e/__init__.py
  - Fix [ 239 ] Latex writer glues paragraphs with figure floats.
  - Apply [ 116 ] by Kirill Smelkov. Don't hardcode \large for subtitle.
  * docutils/writers/odf_odt/__init__.py
  - Apply patch by Jakub Wilk to fix bug [ 100 ].
  * test/test_error_reporting.py
  - Fix [ 223 ] by removing redundant tests we do not have control over.
  * test/test_nodes.py
  - Apply [ 115 ] respect fixed 2to3 string literal conversion behavior.
* Tue Sep 24 2013 toddrme2178@gmail.com
- Update to 0.11
  * Fix for the overwritting of document attributes.
  * Support embedded aliases within hyperlink references.
  * try local import of docutils components (reader, writer, parser,
    language module) before global search.
  * Python 3.3 checks CVS syntax only if "strict" is True.
  * Now, it is easy to add a custom stylesheet to Docutils' default
    stylesheet with, e.g.,
  - -stylesheet_path='html4css1.css, mystyle.css'
  * If there is a file html4css1.css in the working directory of the
    process at launch, it is used instead of the one provided by
    Docutils in the writer source directory.
  * New default for math-output: HTML math.css.
  * Avoid repeated class declarations in html4css1 writer
  * Drop the simple algorithm replacing straight double quotes with
    English typographic ones. Activate the SmartQuotes transform if
    you want this feature.
  * New setting stylesheet_dirs: Comma-separated list of directories
    where stylesheets are found. Used by stylesheet_path when
    expanding relative path arguments.
  * handle lines starting with a period.
  * Fix option separating comma was bold (thanks to Bill Morris).
- Use pypi url and download
- Replace rpmlint-non-executable-scripts.diff with sed in the spec
  file
* Mon Sep 16 2013 tchvatal@suse.com
- Fix the symlink creation.
* Mon Sep 16 2013 tchvatal@suse.com
- Drop r7486-python33-compat.patch as it is not needed.
* Mon Sep 16 2013 tchvatal@suse.com
- Use update-alternatives to allow switching between py2 and py3
  version of doctool binaries.
* Wed Jul  3 2013 dmueller@suse.com
- update to 0.10:
  - add rpmlint-non-executable-scripts.diff
  * SmartQuotes transform for typographic quotes and dashes.
  * FileInput/FileOutput: no system-exit on IOError. The handle_io_errors option is ignored.
  * <code> tag for inline "code", do not drop nested inline nodes (syntax highlight tokens).
  * Customizable MathJax URL (based on patch by Dmitry Shachnev).
  * No line break after opening inline math tag.
* Tue Nov 20 2012 saschpe@suse.de
- Run testsuite
- Correctly fix non-excutable script warning
- Remove outdated macros
- Also remove "*.py" ending in egg-info files
* Fri Oct 26 2012 highwaystar.ru@gmail.com
- patch from upstream for python3.3 support
  * Fix [3541369] Relative __import__ also with Python 3.3
* Thu May  3 2012 toddrme2178@gmail.com
- Update to version 0.9:
  * reStructuredText "code" role and directive with syntax
    highlighting by Pygments_.
  * "code" option of the "include" directive.
  * Fix [ 3402314 ] allow non-ASCII whitespace, punctuation
    characters and "international" quotes around inline markup.
  * Fix handling of missing stylesheets.
  * Fix [ 2971827 ] and [ 3442827 ] extras/roman.py moved to
    docutils/utils/roman.py
  * docutils.utils is now a package (providing a place for
    sub-modules)
  * change default for `math-output` setting to MathJax
  * Support the `abbreviation` and `acronym` standard roles.
  * Record only files required to generate the LaTeX source as
    dependencies.
  * Use ``\setcounter{secnumdepth}{0}`` instead of ``*``-versions
    when suppressing LaTeX section numbering.
- Cleaned up spec files
- Fix rpmlint warnings
* Mon Apr 30 2012 cfarrell@suse.com
- license update: Python-2.0 and BSD-2-Clause and GPL-2.0+ and GPL-3.0+ and
  SUSE-Public-Domain
  tools/editors/emacs/rst.el is GPL-3.0+ - see also COPYING file
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Tue Apr 24 2012 saschpe@suse.de
- Disable testsuite altogether, fails also on the bleeding_edge_* repos
* Tue Feb 28 2012 saschpe@suse.de
- Fixed SLE_11_SP2 build by disabling the testsuite
* Fri Sep 23 2011 saschpe@suse.de
- Fixed build:
  * python-xml is only required on SUSE
  * pyxml is required on Fedora (and RHEL)
* Wed Sep 21 2011 saschpe@suse.de
- Don't run tests on SLE, they break the build
* Wed Sep 21 2011 saschpe@suse.de
- Renamed to python-docutils (from docutils), also fixes rpmlint
  warning about naming policy
- Update to version 0.8.1:
  * Change last file with Apache license to BSD-2-Clause and correct copyright
    info for rst.el
  * Fix tests under py3k.
  * Clean up Babel language setting. Restores Sphinx compatibility.
- Changes from version 0.8.0:
  * Some additions to the Docutils core are released under the 2-Clause BSD
    license.
  * Handle language codes according to BCP 47.
  * If the specified langauage is not supported by Docutils, warn and fall
    back to English.
  * Math support: reStructuredText "math" role and directive, math and
    math_block doctree elements.
  * Orphaned "python" reader and "newlatex2e" writer moved to the sandbox.
  * Added lithuanian mappings.
- Changes from version 0.7.0:
  * Support SVG and SWF images
  * Generate valid XHTML for centered images with targets. Use CSS classes
    instead of "align" tags for image alignment.
  * Preserve runs of spaces in 'inline literals'.
  * Deprecate figure_footnotes setting.
  * Rename use_latex_footnotes setting to docutils_footnotes.
  * New latex_preamble setting.
  * Use PDF standard fonts (Times/Helvetica/Courier) as default.
  * hyperref package called with unicode option
  * Drop the special output_encoding default ("latin-1"). The Docutils wide
    default (usually "UTF-8") is used instead.
- Spec file cleanup:
  * Removed outdated docutils-0.6-insecure-temp.patch
  * Fixed non-executable scripts rpmlint warning
  * Removed ".py" ending from executables in /usr/bin, this is what
    other Python packages expect anyway
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Dec 20 2010 saschpe@suse.de
- reduce rpmlint complaints:
  * name in summary
  * executables in doc package ('tools' folder)
* Sun Dec 12 2010 saschpe@gmx.de
- update to 0.6
  * support for SVG and SWF images in HTML writer
  * many improvements in LaTeX2e writer
- re-generated spec file with py2pack
  * now builds for Fedora and Mandriva
* Thu Mar 18 2010 matejcik@suse.cz
- update to 0.6
  * scaling figures/images by percents
  * many improvements in LaTeX2e writer
- fixed insecure usage of temp files in emacs mode
  (bnc#564366)
* Tue Aug 11 2009 matejcik@suse.cz
- build as noarch on new distros
* Wed Aug  5 2009 matejcik@suse.cz
- update to 0.5
  * added hebrew mappings
  * configuration is now in UTF-8
  * minor fixes and refactoring
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 cthiel@suse.de
- update to 0.4
* Tue May 31 2005 ltinkl@suse.cz
- update to 0.3.9
* Mon Jan  3 2005 mcihar@suse.cz
- update to 0.3.7
* Fri Jul 30 2004 mcihar@suse.cz
- update to 0.3.5
* Mon May 31 2004 mcihar@suse.cz
- updated to 0.3.3-alpha
* Thu Mar 18 2004 mcihar@suse.cz
- corrected python dependency
* Tue Feb 10 2004 vinil@suse.cz
- initial version (CVS from 2004-02-10)
